Module operator

Module operator 

Structs

OperatorConfig

Traits

OneInOneOut
The OneInOneOut trait must be implemented by operators that consume data from their input read stream, and generate output on an output write stream. The operator can either choose to consume data from its read_stream itself using the run method, or register for the on_data and on_watermark callbacks.
OneInTwoOut
The OneInTwoOut trait must be implemented by operators that consume data from their input read stream, and generate output on two output write streams. The operator can either choose to consume data from its read_stream itself using the run method, or register for the on_data and on_watermark callbacks.
ParallelOneInOneOut
The ParallelOneInOneOut trait must be implemented by operators that consume data from their input read stream, and generate output on an output write stream. The operator can either choose to consume data from its read_stream itself using the run method, or register for the on_data and on_watermark callbacks.
ParallelOneInTwoOut
The ParallelOneInTwoOut trait must be implemented by operators that consume data from their input read stream, and generate output on two output write streams. The operator can either choose to consume data from its read_stream itself using the run method, or register for the on_data and on_watermark callbacks.
ParallelSink
The ParallelSink trait must be implemented by operators that consume data from their input read stream, and do not generate any output. The operator can either choose to consume data from its read_stream itself using the run method, or register for the on_data and on_watermark callbacks.
ParallelTwoInOneOut
The ParallelTwoInOneOut trait must be implemented by operators that consume data from two input read streams, and generate output on an output write stream. The operator can either choose to consume data from its read_stream itself using the run method, or register for the on_data and on_watermark callbacks.
Sink
The Sink trait must be implemented by operators that consume data from their input read stream, and do not generate any output. The operator can either choose to consume data from its read_stream itself using the run method, or register for the on_data and on_watermark callbacks.
The Source trait must be implemented by operators that generate data for the rest of the dataflow graph. Specifically, such an operator does not take an input read stream, but generates data on an output write stream. The operator must take control of its execution by implementing the run method, and generating output on the write_stream passed to it.
TwoInOneOut
The TwoInOneOut trait must be implemented by operators that consume data from their input read streams, and generate output on an output write stream. The operator can either choose to consume data from its read_stream itself using the run method, or register for the on_data and on_watermark callbacks.