pub enum SendError {
SerializationError,
IOError,
TimestampError,
Closed,
}Expand description
Error raised when something went wrong while sending on a WriteStream.
Variants
SerializationError
Message serialization failed.
IOError
There was a network or a mpsc::channel error.
TimestampError
Timestamp or watermark is smaller or equal to the low watermark.
Closed
Stream is closed and can no longer send messages.