WriteStream

Struct WriteStream 

pub struct WriteStream<D: Data> { /* private fields */ }
A WriteStream allows operators to send data to other operators.

Data is sent via Messages, which are broadcast to operators that are connected to the stream. Messages are rapidly sent to operators within the same node using zero-copy communication. Messages sent across nodes are serialized using abomonation if possible, before falling back to bincode.

Example

The following example shows an operator which sends a sequence of numbers on a WriteStream, and ensures that downstream operators progress by sending a watermark after each number.

struct CounterOperator {}

impl Source<usize> for CounterOperator {
    fn run(&mut self, config: &OperatorConfig, write_stream: &mut WriteStream<usize>) {
        for t in 0..10 {
            let timestamp = Timestamp::Time(vec![t as u64]);
            write_stream
                .send(Message::new_message(timestamp.clone(), t))
                .unwrap();
            write_stream
                .send(Message::new_watermark(timestamp))
                .unwrap();
            thread::sleep(Duration::from_millis(100));
        }
    }
}

Implementations

Source

impl<D: Data> WriteStream<D>

pub fn id(&self) -> StreamId

Get the ID given to the stream by the constructor

pub fn name(&self) -> String

Get the name of the stream.

pub fn is_closed(&self) -> bool

Returns true if a top watermark message was received or the IngestStream failed to set up.

pub fn clear_state(&mut self, timestamp: Timestamp)

Clears the condition context state.